@@ -34,7 +34,7 @@
 #define CONFIG_PROPERTIES_DISPLAY_STATUS_BAR                  (1<<1)
 #define CONFIG_PROPERTIES_SLIDER_TEXT_ENTRIES                 (1<<2)
 #define CONFIG_PROPERTIES_INCLUDE_DISPLAY_NAME_IN_CONFIG_FILE (1<<3)
-#define CONFIG_PROPERTIES_SHOW_QUIT_DIALOG                    (1<<4)
+#define CONFIG_PROPERTIES_UPDATE_RULES_ON_PROFILE_NAME_CHANGE (1<<4)
 
 typedef struct _TimerConfigProperty {
     char *description;
@@ -50,12 +50,15 @@ typedef struct {
 } ConfigProperties;
 
 
+void set_dynamic_verbosity(int dynamic);
+
 void init_config_properties(ConfigProperties *conf);
 
-int nv_read_config_file(const char *, const char *,
-                        ParsedAttribute *, ConfigProperties *);
+int nv_read_config_file(const Options *, const char *, const char *,
+                        ParsedAttribute *, ConfigProperties *,
+                        CtrlSystemList *);
 
-int nv_write_config_file(const char *, CtrlHandles *,
-                         ParsedAttribute *, ConfigProperties *);
+int nv_write_config_file(const char *, const CtrlSystem *,
+                         const ParsedAttribute *, const ConfigProperties *);
 
 #endif /* __CONFIG_FILE_H__ */
